# A Permutation-Based CCA Analysis Toolbox
**Currently Testing Against the matlab version**

Reference: Winkler AM, Renaud O, Smith SM, Nichols TE. Permutation Inference for Canonical Correlation Analysis. NeuroImage. 2020; 117065

* Returns similar results as the matlab version
* Robust than matlab version thanks to the 'nipals' method in sklearn
* TODO: ADD support for covariates